#
# spec file for package python-tpm2-pytss
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
%define srcname tpm2-pytss
%bcond_with     test
Name:           python-%{srcname}
Version:        2.3.0
Release:        1.2
Summary:        Python bindings for TSS
License:        BSD-2-Clause
URL:            https://github.com/tpm2-software/tpm2-pytss
Source:         %{srcname}-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module asn1crypto}
BuildRequires:  %{python_module cffi}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pkgconfig}
BuildRequires:  %{python_module pycparser}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(tss2-esys)
BuildRequires:  pkgconfig(tss2-fapi)
Requires:       python3-PyYAML
Requires:       python3-asn1crypto
Requires:       python3-cffi
Requires:       python3-cryptography
Requires:       python3-packaging
Requires:       pkgconfig(tss2-esys)
Requires:       pkgconfig(tss2-fapi)
%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  swtpm
# /SECTION
%endif
%python_subpackages

%description
TPM2 TSS Python bindings for Enhanced System API (ESYS), Feature API
(FAPI), Marshaling (MU), TCTI Loader (TCTILdr) and RC Decoding
(rcdecode) libraries. It also contains utility methods for wrapping
keys to TPM 2.0 data structures for importation into the TPM,
unwrapping keys and exporting them from the TPM, TPM-less
makecredential command and name calculations, TSS2 PEM Key format
support, importing Keys from PEM, DER and SSH formats, conversion from
tpm2-tools based command line strings and loading tpm2-tools context
files.

%prep
%autosetup -p1 -n %{srcname}-%{version}

%build
# Provides a PKG-INFO with "version" for setuptools_scm
cat <<EOF > PKG-INFO
Metadata-Version: 1.1
Version:        %{version}
EOF
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with test}
%check
%pytest_arch
%endif

%files %{python_files}
%license LICENSE
%{python_sitearch}/tpm2_pytss
%{python_sitearch}/tpm2_pytss-%{version}.dist-info

%changelog
* Wed Oct  9 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to version 2.3.0:
  * FAPI: support exists_ok for create_nv
  * Compatibility with python-cryptography 42
  * scripts: update regex for #defines
  * cryptography: fixes for newer version of cryptography
  * docs/maintainers: add gpg key details
  * docs: fix whitespace error
  * docs: fix error on SECURITY.md not being used
  * cryptography: add module for using TPM keys with the cryptography module
  * encoding: add deprecation warning to tools_encdec
  * internal/crypto: fix _MyRSAPrivateNumbers with cryptograpy >= 42.0.1
  * test: disable pcr_set_auth_value and pcr_set_auth_policy tests for swtpm
- Drop patch python-tpm2-pytss-RSAPrivateNumbers.patch, included upstream.
- Switch to pyproject macros.
* Wed Feb 28 2024 Pedro Monreal <pmonreal@suse.com>
- Fix tpm2-pkcs11 build:
  * internal/crypto: fix _MyRSAPrivateNumbers with cryptograpy >= 42.0.1
  * Upstream: github.com/tpm2-software/tpm2-pytss/pull/562
  * Add python-tpm2-pytss-RSAPrivateNumbers.patch
* Tue Feb 27 2024 Pedro Monreal <pmonreal@suse.com>
- Update to version 2.2.0:
  * docs: use same requirements as in setup.cfg
  * policy: fix hardcoded size in description
  * policy: fix hardcoded size in get_calculated_json
  * readthedocs: switch to new build specification format
  * test: test against python 3.12
  * test: skip tests if ECC curves aren't supported.
  * init: provide a better error message for missing symbols
  * scripts: remove references to TPMS_ALGORITHM_DESCRIPTION
  * tctildr: use Tss2_TctiLdr_GetInfo to lookup tcti backend
  * setup: fixup compilation with fortify source enabled
  * setup: drop python 3.7
  * test: add check for renamed cryptography types
  * constants: use relative import over absolute
  * constants: support unmarshal and marshal routines
  * ESAPI: fix check on ESYS_TR in policy_secret
  * constants: add routine for making ESYS_TR from parts
  * setup: define __float128 for pycparse
  * Remove fix_pycparse_float128.patch fixed upstream
* Fri Feb 17 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Add fix_pycparse_float128.patch to fix issue in 32bits platforms
* Thu Feb 16 2023 aplanas@suse.com
- Update to version 2.1.0:
  * CHANGELOG: update for 2.1.0
  * SECURITY.md: initial commit
  * TCTISPIHelper: add missing pass
  * TCTISPIHelper: update docs on exceptions
  * build(deps): bump gitpython from 3.1.24 to 3.1.30 in /docs
  * ci: set publish to use ubuntu-20.04
  * CHANGELOG: update for 2.1.0-rc0
  * TCTI: Implement bindings to spi-helper
  * ci: add 4.0.0, drop 2.4.6
  * docs: fix PyTCTI members
  * use released tss2 versions for library version checking
  * build(deps): bump certifi from 2021.10.8 to 2022.12.7 in /docs
  * Add util functions to convert a credential from and to tpm2-tools format
  * ESAPI: start_auth_session support strs for auth_hash
  * ESAPI: start_auth_session support strings for symdef
  * types: add parse to TPMT_SYM_[DEF|_OBJECT]
  * internal: check for sphinx not unittest.mock for docs workaround
* Thu Dec  8 2022 aplanas@suse.com
- Update to version 2.0.0:
  * CHANGELOG: update for 2.0 release
  * CHANGELOG: move breaking items to changed
  * Revert "ci: publish_pkg update to tss 4.0.0-rc0"
  * ci: publish_pkg update to tss 4.0.0-rc0
  * ci: update publish script to py3.7
  * README: Update mailing list
  * CHANGELOG: update for 2.0-rc0
  * docs: add PyTCTI to docs
  * README: add newest libraries
  * FAPI: drop unused import Dict
- Drop patch 0001-test_crypto-fix-test_ecc_bad_curves-assert.patch
* Mon Jul 11 2022 Alberto Planas Dominguez <aplanas@suse.com>
- Initial package for 1.2.0
